==> haskell-static-hash-0.0.2-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-static-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 static-hash
version:              0.0.2
visibility:           public
id:                   static-hash-0.0.2-78XpJ5D7LLpLHydKJv836g
key:                  static-hash-0.0.2-78XpJ5D7LLpLHydKJv836g
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Immutable hash
description:          Pure immutable hash whose lookup is O(1)
category:             Data Structures
abi:                  35b7d9f935c884bc027a6e6dd22ac079
exposed:              True
exposed-modules:      Data.StaticHash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-static-hash
hs-libraries:         HSstatic-hash-0.0.2-78XpJ5D7LLpLHydKJv836g
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-L2Cc1YdcpYH9U2sZW5osde
    primes-0.2.1.0-5dFqmFtEQZu8fMD7oOp1xA

haddock-interfaces:   /usr/share/doc/haskell-static-hash/html/static-hash.haddock
haddock-html:         /usr/share/doc/haskell-static-hash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-static-hash-0.0.2-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-static-hash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 static-hash
version:              0.0.2
visibility:           public
id:                   static-hash-0.0.2-H3rPSiWydYhFPjTYsS7zKq
key:                  static-hash-0.0.2-H3rPSiWydYhFPjTYsS7zKq
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Immutable hash
description:          Pure immutable hash whose lookup is O(1)
category:             Data Structures
abi:                  4d88b95ec678620a81988fcfc49fa130
exposed:              True
exposed-modules:      Data.StaticHash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/static-hash-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-static-hash
hs-libraries:         HSstatic-hash-0.0.2-H3rPSiWydYhFPjTYsS7zKq
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-2TMrYujL0SWBJEdw6jCOMM
    primes-0.2.1.0-5dFqmFtEQZu8fMD7oOp1xA

haddock-interfaces:   /usr/share/doc/haskell-static-hash/html/static-hash.haddock
haddock-html:         /usr/share/doc/haskell-static-hash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
